pub enum Verdict {
Proceed,
Replay {
code: ErrorCode,
at: String,
},
Wait {
code: ErrorCode,
at: String,
remaining_secs: u64,
},
}Expand description
What a new request for a ref should do.
Variants
Proceed
Ask the network.
Replay
Report the earlier answer again without asking.
Wait
The earlier answer said to back off, and not long enough ago.